.. _Foundation: http://github.com/zurb/foundation
.. _modular-scale: https://github.com/scottkellum/modular-scale
.. _Compass: http://compass-style.org/
.. _Django: http://www.djangoproject.com/
.. _rvm: http://rvm.io/
.. _yui-compressor: http://developer.yahoo.com/yui/compressor/
.. _webassets: https://github.com/miracle2k/webassets
.. _virtualenv: http://www.virtualenv.org/
.. _Jinja2: http://jinja.pocoo.org/
.. _watchdog: https://github.com/gorakhargosh/watchdog
.. _Babel: https://pypi.python.org/pypi/Babel
.. _Optimus-foundation: https://github.com/sveetch/Optimus-foundation

Introduction
============

A simple building environment to produce static HTML from `Jinja2`_ templates and with assets compress managing with `webassets`_.

The environment should bring all needed stuff and command lines to build static websites with benefit of templating with `Jinja2`_, compressed assets (for production) with `webassets`_ and cohabits with Compass or Less.

Read the Optimus documentation on `<https://optimus.readthedocs.org/>`_
